@@ -1,29 +1,39 @@
 try:
     from email.parser import Parser
-except ImportError:
+except ImportError: #pragma NO COVER
+    # Python < 2.5
     import rfc822
     def parse(fp):
         return rfc822.Message(fp)
     def get(msg, header):
-        return _collapse_leading_ws(msg.getheader(header))
+        return _collapse_leading_ws(header, msg.getheader(header))
     def get_all(msg, header):
-        return [_collapse_leading_ws(x) for x in msg.getheaders(header)]
-else:
+        return [_collapse_leading_ws(header, x)
+                    for x in msg.getheaders(header)]
+else: # Python >= 2.5
     def parse(fp):
         return Parser().parse(fp)
     def get(msg, header):
-        return _collapse_leading_ws(msg.get(header))
+        return _collapse_leading_ws(header, msg.get(header))
     def get_all(msg, header):
-        return [_collapse_leading_ws(x) for x in msg.get_all(header)]
+        return [_collapse_leading_ws(header, x) for x in msg.get_all(header)]
 
-def _collapse_leading_ws(txt):
-    return ' '.join([x.strip() for x in txt.splitlines()])
+def _collapse_leading_ws(header, txt):
+    """
+    ``Description`` header must preserve newlines; all others need not
+    """
+    if header.lower() == 'description':  # preserve newlines
+        return '\n'.join([x[8:] if x.startswith(' ' * 8) else x
+                          for x in txt.strip().splitlines()])
+    else:
+        return ' '.join([x.strip() for x in txt.splitlines()])
 
 try:
-    from StringIO import StringIO
-except ImportError:
     from io import StringIO
-    
+except ImportError: #pragma NO COVER
+    # Python < 2.6
+    from StringIO import StringIO
+ 
 
 HEADER_ATTRS_1_0 = ( # PEP 241
     ('Metadata-Version', 'metadata_version', False),
